<?php
/**
 * @package     Sven.Bluege
 * @subpackage  com_eventgallery
 *
 * @copyright   Copyright (C) 2005 - 2019 Sven Bluege All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */
namespace Svenbluege\Component\Eventgallery\Administrator\Controller;
defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\Controller\FormController;
use Joomla\CMS\Session\Session;
use Svenbluege\Component\Eventgallery\Administrator\Model\GooglephotossyncModel;
use \Svenbluege\Component\Eventgallery\Site\Library\Connector\GooglePhotosConnector;
use Svenbluege\Component\Eventgallery\Site\Library\Factory\GooglePhotosAccountFactory;

class GooglephotossyncController extends FormController
{

    protected $default_view = 'googlephotossync';

    /**
     * function to provide the Google Photos Sync-View
     * @throws \Exception
     */
	function sync()
	{
        Session::checkToken() or jexit(Text::_('JINVALID_TOKEN'));

        $app = Factory::getApplication();
        $db = Factory::getDbo();

        $accountId = $this->input->getInt('googlephotosaccountid');
        $isDryRun = $this->input->getBool('dryrun');

        /**
         * @var GooglePhotosAccountFactory $accountFactory
         */

        $accountFactory = GooglePhotosAccountFactory::getInstance();
        $account = $accountFactory->getAccountById($accountId);

        $albums = GooglePhotosConnector::getAlbums(COM_EVENTGALLERY_GOOGLE_PHOTOS_ALBUMS_CACHE_LIFETIME, $account->getClientId(), $account->getSecret(), $account->getRefreshToken(), $db);

        /**
         * @var GooglephotossyncModel $model
         */
        $model = $this->getModel();
        $albumsAdded = 0;

        if (!empty($albums)) {
            foreach ($albums as $album) {

                if (!$model->eventExists($album->id)) {
                    if (!$isDryRun) {
                        $model->addEvent($account->getId(), $album);
                    }
                    $albumsAdded++;
                }
            }
        }

        if ($isDryRun) {
            $app->enqueueMessage(Text::sprintf('COM_EVENTGALLERY_GOOGLEPHOTOSSYNC_DRYRUN_DONE', $albumsAdded));
        }
        $app->enqueueMessage(Text::sprintf('COM_EVENTGALLERY_GOOGLEPHOTOSSYNC_DONE', $albumsAdded));

        $this->display();
	}

	public function cancel($key = NULL) {
		$this->setRedirect( 'index.php?option=com_eventgallery&view=eventgallery');
	}
}
